ata_glpk solves the the MIP model using GLPK
helper functions for ATA
ata_check_item_pool checks the input of the item pool
ata_item_set_groups creates grouping indices for item sets
ata_form_map creates a map of external and internal forms
ata_get_form_index finds the internal form indices for the form input
ata_get_obj_coef finds real coefficients for the coefficient input
ata_append appends constraints to the ATA model
x retrieves items from the result matrix
ata_results_to_model converts results from the 'by-form' format to the 'by-model' format
ata_results_to_dataframe converts results from the 'by-model' format to the 'data.frame' format
ata_lpsolve solves the the MIP model using lp_solve
ata_glpk(x, time_limit, message, ...)ata_check_item_pool(pool)
ata_item_set_groups(pool, opts)
ata_form_map(n_forms, opts)
ata_get_form_index(x, forms, collapse, internal_index)
ata_get_obj_coef(x, coef, compensate)
ata_append(x, mat, dir, rhs)
ata_extract_items(x)
ata_results_to_model(items)
ata_results_to_dataframe(items)
ata_lpsolve(x, time_limit, message, ...)
an ATA object
the time limit in seconds passed along to the solver
TRUE to print messages from the solver
additional control parameters for the solver
the item pool, a list of 3pl, gpcm, and grm items
the options, a list
the nubmer of forms to be assembled
form indices
TRUE to collaspe forms into one form
TRUE to use internal form index
coefficients
TRUE to combine coefficients
coefficient matrix
direction
right-hand-side value
the assembled items